===============
Topic Modelling
===============

.. figure:: icons/topicmodelling.png

Topic modelling with Latent Diriclet Allocation.

Signals
-------

**Inputs**:

-  **Corpus**

Corpus instance.

**Outputs**:

-  **Data**

Data with topic weights appended.

-  **Topics**

Selected topics with word weights.

Description
-----------

No description yet for this widget.

Example
-------

No example yet for this widget.

